GradStore

Struct GradStore 

pub struct GradStore(/* private fields */);
A store for gradients, associating a tensor id to the corresponding gradient tensor, used for back propagation.

Implementations

Source

impl GradStore

pub fn get_id(&self, id: TensorId) -> Option<&Tensor>

Get the gradient tensor corresponding to the given tensor id

pub fn get(&self, tensor: &Tensor) -> Option<&Tensor>

Get the gradient tensor associated with the given tensor

pub fn remove(&mut self, tensor: &Tensor) -> Option<Tensor>

Remove the gradient tensor associated with the given tensor, returning it if it exists

pub fn insert(&mut self, tensor: &Tensor, grad: Tensor) -> Option<Tensor>

Insert a gradient tensor associated with the given tensor, returning the previous gradient tensor if it existed

pub fn insert_id(&mut self, id: TensorId, grad: Tensor) -> Option<Tensor>

Insert a gradient tensor associated with the given tensor id, returning the previous gradient tensor if it existed

pub fn extend(&mut self, other: Self) -> Result<()>

Extend this gradient store with the contents of another. If an entry is already occupied, updates and ensures new tensor follows correct detach semantics. Otherwise simply inserts.

pub fn get_ids(&self) -> impl Iterator<Item = &TensorId>

Get the tensor ids of the stored gradient tensors